Contributing
============

See the `CONTRIBUTING <https://github.com/wigging/chemics/blob/main/CONTRIBUTING.md>`_ document on GitHub for guidelines on contributing to the Chemics package. Thank you for contributing!
